# Tutorials

The following examples showcase how features of `bijx` can be combined into a more complete workflow including training.

```{toctree}
:maxdepth: 2
:caption: Examples:

tutorials/continuous
tutorials/gmm-spiral
tutorials/scalar-theory
tutorials/su3-flow
```
